@@ -20,10 +20,11 @@
 #' Atlantic-centred. Works for most analysis, but not recommended for N-region
 #' (eg New Zealand and Fiji), instead use \code{\link{crs_Pacific}}.
 #'
-#' crs_Atlantic is "+proj=robin +lon_0=0 +x_0=0 +y_0=0 +ellps=WGS84
-#' +datum=WGS84 +units=m +no_defs"
+#' crs_Atlantic is "+proj=robin +lon_0=0 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84
+#' +units=m +no_defs"
 #'
-#' @seealso \code{\link{crs_Pacific}}, \code{\link{crs_N}}, \code{\link{crs_S}}
+#' @seealso \code{\link{crs_Pacific}}, \code{\link{crs_120E}},
+#'   \code{\link{crs_N}}, \code{\link{crs_S}}
 #'
 #' @format CRS
 #'
@@ -34,14 +35,31 @@
 #' Coordinate reference system (CRS) for plotting and analysing maps.
 #' Pacific-centred.
 #'
-#' "+proj=robin +lon_0=180 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs"
+#' "+proj=robin +lon_0=180 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m
+#' +no_defs"
 #'
 #' @format CRS
 #'
-#' @seealso \code{\link{crs_Atlantic}}, \code{\link{crs_N}}, \code{\link{crs_S}}
+#' @seealso \code{\link{crs_Atlantic}}, \code{\link{crs_120E}},
+#'   \code{\link{crs_N}}, \code{\link{crs_S}}
 #'
 "crs_Pacific"
 
+#' Asia-centred coordinate reference system
+#'
+#' Coordinate reference system (CRS) for plotting and analysing maps. Centred on
+#' East Asia (120E).
+#'
+#' "+proj=robin +lon_0=120 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m
+#' +no_defs"
+#'
+#' @format CRS
+#'
+#' @seealso \code{\link{crs_Atlantic}}, \code{\link{crs_Pacific}},
+#'   \code{\link{crs_N}}, \code{\link{crs_S}}
+#'
+"crs_120E"
+
 #' Arctic-centred coordinate reference system
 #'
 #' Coordinate reference system (CRS) for plotting and analysing maps.
@@ -51,7 +69,7 @@
 #' crs_N is EPSG3995
 #'
 #' @seealso \code{\link{crs_Atlantic}}, \code{\link{crs_Pacific}},
-#'  \code{\link{crs_longlat}}, \code{\link{crs_S}}
+#'  \code{\link{crs_120E}}, \code{\link{crs_longlat}}, \code{\link{crs_S}}
 #'
 #' @format CRS
 #'
@@ -66,7 +84,7 @@
 #' crs_N is EPSG 3031
 #'
 #' @seealso \code{\link{crs_Atlantic}}, \code{\link{crs_Pacific}},
-#'  \code{\link{crs_longlat}}, \code{\link{crs_N}}
+#'  \code{\link{crs_120E}}, \code{\link{crs_longlat}}, \code{\link{crs_N}}
 #'
 #' @format CRS
 #'
